/* GCC */

#include <cstdio>
#include <cmath>
#include <utility>
#include <algorithm>
#include <vector>
#include <set>
#include <ctime>

using namespace std;

const int MaxS = 20;
const int MaxC = MaxS*MaxS;

int S, C;
pair<int, int> adj[MaxC];

int calc_cost(const vector<int> &perm)
{
  int *inv_perm;
  inv_perm = new int[S];
  for (int i = 0; i < S; i++)
    inv_perm[perm[i]] = i;

  int cost = 0;
  for (int i = 0; i < C; i++)
    cost += abs(inv_perm[ adj[i].first ] - inv_perm[ adj[i].second ]);
  delete inv_perm;
  return cost;
}

int main()
{
  //   
  freopen("servers.in", "rt", stdin);
  scanf("%d %d", &S, &C);
  for (int i = 0; i < C; i++) {
    scanf("%d %d", &adj[i].first, &adj[i].second);
    adj[i].first--;
    adj[i].second--;
  }

  vector< pair<int, int> > S2;
  for (int i = 0; i < S; i++)
    for (int j = 0; j < i; j++)
      S2.push_back(make_pair(i, j));

  vector<int> perm(S), best_perm;
  int best_cost = S*S*S;
  int best_count = 0;
  for (int i = 0; i < S; i++)
    perm[i] = i;

  for (int num_permutations = 0; num_permutations <= 250; num_permutations++) {
    random_shuffle(perm.begin(), perm.end());
    random_shuffle(S2.begin(), S2.end());

    while (true) {
      int cost = calc_cost(perm);

      vector<int> next_perm;
      int next_cost = cost;

      for (int k = 0; k < S2.size(); k++) {
	int i = S2[k].first, j = S2[k].second;
	vector<int> test = perm;
	swap(test[i], test[j]);
	int test_cost = calc_cost(test);

	if (test_cost < next_cost) {
	  next_cost = test_cost;
	  next_perm = test;
	}
      }

      if (next_cost >= cost)
	break;

      perm = next_perm;
    }

    int current_cost = calc_cost(perm);
    if (current_cost < best_cost) {
      best_cost = current_cost;
      best_perm = perm;
      best_count = 0;
    }
    if (current_cost == best_cost)
      best_count++;
  }

  //  
  freopen("servers.out", "wt", stdout);
  printf("%d\n", best_cost);
  for (int i = 0; i < S; i++) {
    if (i)
      putchar(' ');
    printf("%d", best_perm[i]+1);
  }
  puts("");

	FILE * timing = fopen("timing","a+");
	fprintf(timing, "servers %lf\n", 1.0*clock()/CLOCKS_PER_SEC);
	fclose(timing);
  return 0;
}